---
name: "🐛 Bug report"
about: "If something isn't working 🔧"
title: ''
labels: bug
assignees: ''

---

## :bug: Bug Report

<!-- A clear and concise description of what the bug is. -->
<!-- If applicable, add screenshots to help explain your problem. -->

## :microscope: How To Reproduce

Steps to reproduce the behavior:

1. ...

### Code sample

<!-- If applicable, attach a minimal code sample to reproduce the issue. -->

### Environment

- OS: (e.g. Linux / Windows / macOS)
- Python version: `python --version`
- Package version: (e.g. `main`, `v1.0.1`, `fa1a1c8`)

## :chart_with_upwards_trend: Expected Behavior

<!-- A clear and concise description of what you expected to happen. -->

## :paperclip: Additional Context

<!-- Add any other context about the problem here. -->
